@@ -8,7 +8,6 @@ import time
 import re
 import builtins
 from typing import Union
-from colorama import Fore, Back, init, Style
 
 from .utils import deep_merge, send_email, get, cast
 from .exception import AppToolError
@@ -254,7 +253,7 @@ class AppTool(object):
         
     
     def D(self, *args):
-        '''色彩打印 DEBIG
+        '''色彩打印 DEBUG
         '''
         self.print('DEBUG', *args)
 
@@ -274,15 +273,21 @@ class AppTool(object):
     def print(self, level, *args):
         local_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
         if level == 'DEBUG':
-            color = Fore.YELLOW
+            header = '1;33;44'
+            fg = 33
         elif level == 'INFO':
-            color = Fore.GREEN
+            header = '5;34;43'
+            fg = 32
         elif level == 'ERROR':
-            color = Fore.RED
+            header = '1;33;41'
+            fg = 31
         else:
-            color = Fore.BLUE
-        print(color, '{} [{}] - {} - '.format(local_time, self.name, level), *args)
-        print(Style.RESET_ALL, flush=True)
+            header = '5;30;46'
+            fg = 34
+        app_header = '5;34;47'
+        message = f'{local_time} \x1b[{app_header}m[{self.name}]\x1b[0m - \x1b[{header}m{level:5}\x1b[0m - \x1b[{fg}m'
+        print(message, *args, )
+        print('\x1b[0m', flush=True)
 
 
     def log(self, throw=False, message=''):
