@@ -152,7 +152,7 @@ def send_email(from_addr: str, to_addrs: str, subject: str, text_body: str='', s
     # generic email headers
     msg['From'] = from_addr
     msg['To'] = to_addrs
-    msg['Subject'] = subject
+    msg['Subject'] = subject.replace('\n','').replace('\r','')
 
     # set the plain text body
     msg.set_content(text_body)
@@ -484,4 +484,48 @@ def find_free_port():
     with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
         s.bind(('', 0))
         s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-        return s.getsockname()[1]
\ No newline at end of file
+        return s.getsockname()[1]
+        
+        
+def print_color_table():
+    """
+    prints table of formatted text format options
+    """
+    for style in range(8):
+        for fg in range(30, 38):
+            s1 = ''
+            for bg in range(40, 48):
+                format = ';'.join([str(style), str(fg), str(bg)])
+                s1 += '\x1b[%sm %s \x1b[0m' % (format, format)
+                usage = f'Format: effect;foreground;background (Ex. \\x1b[{format}m {format} \\x1b[0m)'
+    
+            print(s1)
+        print(usage)
+    print()
+    
+    
+def timestamp()->str:
+    return time.strftime("%Y%m%d_%H%M%S", time.localtime())
+
+
+def pad_filename(filename:str, pad:str=None, template:str=None)->str:
+    """Pad some text into filename by template
+
+    Args:
+        template (str, optional): [template to pad]. Defaults to None.
+        PAD, FILENAME, FILEEXT are available in the template.
+        Ex. '{FILENAME}_{PAD}.{FILEEXT}'
+        If template is None, '{FILENAME}_`timestamp`.{FILEEXT}' will be used.
+
+    Returns:
+        str: [padded filename]
+    """
+    fpath, fullname = path.split(filename)
+    name, ext = path.splitext(fullname)
+    if template is None:
+        if ext:
+            template = '{FILENAME}_{PAD}.{FILEEXT}'
+        else:
+            template = '{FILENAME}_{PAD}'
+        pad = timestamp()
+    return path.join(fpath, template.format(FILENAME=name, FILEEXT=ext[1:], PAD=pad))
\ No newline at end of file
